=========
Changelog
=========

Version 0.1.4

- Bugfixes related to perusat_orthorectify CLI script.

Version 0.1.3
=============

- Applied nodata fill algorithm to SRTM DEM to avoid artifacts when
  orthorectifying.

Version 0.1.2
=============

- Support optional OTB_ENV_PATH environment variable, to load OTB environment
  only when running OTB CLI commands internally.
- Various bugfixes for making it work on Windows.

Version 0.1.0
=============

- Basic processing scripts for calibration, orthorectification and
  pansharpening.
